@@ -16,20 +16,16 @@ from cubicweb.utils import transitive_closure_of
 from cubicweb.schema import META_RTYPES
 from cubicweb.selectors import is_instance
 from cubicweb.server import hook
-from cubicweb.server.hook import (Hook, PropagateRelationHook,
-                                  PropagateRelationAddHook,
-                                  PropagateRelationDelHook,
-                                  match_rtype, match_rtype_sets)
 from cubicweb.hooks import notification
 
 # automatization hooks #########################################################
 
-class VersionStatusChangeHook(Hook):
+class VersionStatusChangeHook(hook.Hook):
     """when a ticket is done, automatically set its version'state to 'dev' if
       necessary
     """
     __regid__ = 'version_status_change_hook'
-    __select__ = Hook.__select__ & hook.match_rtype('in_state',)
+    __select__ = hook.Hook.__select__ & hook.match_rtype('in_state',)
     events = ('after_add_relation',)
     ticket_states_start_version = set(('in-progress',))
 
@@ -46,12 +42,12 @@ class VersionStatusChangeHook(Hook):
                 versioniwf.fire_transition('start development')
 
 
-class TicketDoneInChangeHook(Hook):
+class TicketDoneInChangeHook(hook.Hook):
     """when a ticket is attached to a version and it's identical to another one,
     attach the other one as well
     """
     __regid__ = 'ticket_done_in_change'
-    __select__ = Hook.__select__ & hook.match_rtype('done_in',)
+    __select__ = hook.Hook.__select__ & hook.match_rtype('done_in',)
     events = ('after_add_relation',)
 
     def __call__(self):
@@ -68,12 +64,12 @@ class TicketDoneInChangeHook(Hook):
                     self.exception("can't synchronize version")
 
 
-class TicketStatusChangeHook(Hook):
+class TicketStatusChangeHook(hook.Hook):
     """when a ticket status change and it's identical to another one, change the
     state of the other one as well
     """
     __regid__ = 'ticket_status_change_hook'
-    __select__ = Hook.__select__ & is_instance('TrInfo')
+    __select__ = hook.Hook.__select__ & is_instance('TrInfo')
     events = ('after_add_entity',)
 
     def __call__(self):
@@ -99,32 +95,12 @@ class TicketStatusChangeHook(Hook):
                 except:
                     self.exception("can't synchronize identical ticket's state")
 
+
 # verification hooks ###########################################################
 
-# XXX do this using RQLUniqueConstraint on Version.num and version_of
-class CheckVersionNameOfAProject(Hook):
-    """check that the a version of the same project with the same num doesn't
-    already exist
-    """
-    __regid__ = 'check_version_name_of_a_project'
-    __select__ = Hook.__select__ & hook.match_rtype('version_of',)
-    events = ('before_add_relation',)
-
-    def __call__(self):
-        entity = self._cw.entity_from_eid(self.eidfrom)
-        project = self._cw.entity_from_eid(self.eidto)
-        rset = self._cw.execute(
-            'Any X WHERE X num %(num)s, X version_of P, P eid %(p)s',
-            {'num': entity.num, 'p': project.eid})
-        if rset and (len(rset)>1 or rset[0][0] != entity.eid):
-            msg = self._cw._(u'%(vnum)s release number already exists for the project %(prj)s') % {
-                'vnum': entity.num, 'prj': project.name}
-            raise ValidationError(entity.eid, {"num": msg})
-
-
-class CheckProjectCyclesHook(Hook):
+class CheckProjectCyclesHook(hook.Hook):
     __regid__ = 'check_project_cycles'
-    __select__ = Hook.__select__ & hook.match_rtype('subproject_of',)
+    __select__ = hook.Hook.__select__ & hook.match_rtype('subproject_of',)
     events = ('before_add_relation',)
 
     def __call__(self):
@@ -148,9 +124,9 @@ class BeforeUpdateTicket(notification.EntityUpdateHook):
     __select__ = notification.EntityUpdateHook.__select__ & is_instance('Ticket')
     skip_attrs = META_RTYPES | set(('done_in', 'concerns', 'description_format'))
 
-class BeforeInVersionChangeHook(Hook):
+class BeforeInVersionChangeHook(hook.Hook):
     __regid__ = 'before_in_version_change'
-    __select__ = Hook.__select__ & hook.match_rtype('done_in',)
+    __select__ = hook.Hook.__select__ & hook.match_rtype('done_in',)
     events = ('before_add_relation',)
 
     def __call__(self):
@@ -188,28 +164,28 @@ SKIP_S_RELS = set()
 SKIP_O_RELS = set()
 
 
-class AddEntitySecurityPropagationHook(PropagateRelationHook):
+class AddEntitySecurityPropagationHook(hook.PropagateRelationHook):
     """propagate permissions when new entity are added"""
     __regid__ = 'add_entity_security_propagation'
-    __select__ = (PropagateRelationHook.__select__
-                  & match_rtype_sets(S_RELS, O_RELS))
+    __select__ = (hook.PropagateRelationHook.__select__
+                  & hook.match_rtype_sets(S_RELS, O_RELS))
     main_rtype = 'require_permission'
     subject_relations = S_RELS
     object_relations = O_RELS
 
 
-class AddPermissionSecurityPropagationHook(PropagateRelationAddHook):
+class AddPermissionSecurityPropagationHook(hook.PropagateRelationAddHook):
     __regid__ = 'add_permission_security_propagation'
-    __select__ = (PropagateRelationAddHook.__select__
+    __select__ = (hook.PropagateRelationAddHook.__select__
                   & hook.match_rtype('require_permission'))
     subject_relations = S_RELS
     object_relations = O_RELS
     skip_subject_relations = SKIP_S_RELS
     skip_object_relations = SKIP_O_RELS
 
-class DelPermissionSecurityPropagationHook(PropagateRelationDelHook):
+class DelPermissionSecurityPropagationHook(hook.PropagateRelationDelHook):
     __regid__ = 'del_permission_security_propagation'
-    __select__ = (PropagateRelationDelHook.__select__
+    __select__ = (hook.PropagateRelationDelHook.__select__
                   & hook.match_rtype('require_permission'))
     subject_relations = S_RELS
     object_relations = O_RELS
@@ -219,10 +195,10 @@ class DelPermissionSecurityPropagationHook(PropagateRelationDelHook):
 
 # has_group_permission propagation hooks #######################################
 
-class AddGroupPermissionSecurityPropagationHook(Hook):
+class AddGroupPermissionSecurityPropagationHook(hook.Hook):
     """propagate on group users when a permission is granted to a group"""
     __regid__ = 'add_group_permission_security_propagation'
-    __select__ = Hook.__select__ & hook.match_rtype('require_group',)
+    __select__ = hook.Hook.__select__ & hook.match_rtype('require_group',)
     events = ('after_add_relation',)
     rql = ('SET U has_group_permission P WHERE U in_group G, P eid %(p)s, G eid %(g)s,'
            'NOT U has_group_permission P')
@@ -241,10 +217,10 @@ class DelGroupPermissionSecurityPropagationHook(AddGroupPermissionSecurityPropag
            'NOT EXISTS(U in_group G2, P require_group G2)')
 
 
-class AddInGroupSecurityPropagationHook(Hook):
+class AddInGroupSecurityPropagationHook(hook.Hook):
     """propagate group permission to users when a permission is granted to a group"""
     __regid__ = 'add_in_group_permission_security_propagation'
-    __select__ = Hook.__select__ & hook.match_rtype('in_group',)
+    __select__ = hook.Hook.__select__ & hook.match_rtype('in_group',)
     events = ('after_add_relation',)
     rql = ('SET U has_group_permission P WHERE U eid %(u)s, P require_group G, '
            'G eid %(g)s, NOT U has_group_permission P')
