@@ -178,8 +178,9 @@ class External2SourceConfiguration(TestServerConfiguration):
                          }
         return res
 
-def ms_test_init():
-    repo2, cnx2 = init_test_database(config=ExternalSourceConfiguration('data'))
+def ms_test_init(apphome):
+    repo2, cnx2 = init_test_database(config=ExternalSourceConfiguration(
+        'data2', apphome=apphome))
     cu = cnx2.cursor()
     ep1eid = cu.execute('INSERT Project X: X name "Extern project 1"')[0][0]
     ep1v1eid = cu.execute('INSERT Version V: V num "0.1.0", V version_of X WHERE X name "Extern project 1"')[0][0]
@@ -187,7 +188,8 @@ def ms_test_init():
     ep2v1eid = cu.execute('INSERT Version V: V num "0.1.0", V version_of X WHERE X name "Extern project 2"')[0][0]
     cnx2.commit()
 
-    repo3, cnx3 = init_test_database(config=External2SourceConfiguration('data'))
+    repo3, cnx3 = init_test_database(config=External2SourceConfiguration(
+        'data3', apphome=apphome))
     cu3 = cnx3.cursor()
     e2p1eid = cu3.execute('INSERT Project X: X name "Extern2 project 1"')[0][0]
     cnx3.commit()
