@@ -11,6 +11,7 @@ from datetime import datetime
 from cubicweb.selectors import is_instance, match_transition, attribute_edited
 from cubicweb.web import uicfg, formfields
 from cubicweb.web.views import workflow, editviews
+from cubicweb.web.views.autoform import AutomaticEntityForm
 
 
 _afs = uicfg.autoform_section
@@ -44,7 +45,7 @@ def ticket_done_in_choices(form, field):
             'Any V, VN, P ORDERBY version_sort_value(VN) '
             'WHERE V version_of P, P eid %(p)s, V num VN, '
             'V in_state ST, NOT ST name "published"', {'p': peid})
-        vocab += [(v.view('combobox'), v.eid) for v in rset.entities()
+        vocab += [(v.view('combobox'), unicode(v.eid)) for v in rset.entities()
                   if rschema.has_perm(form._cw, 'add', toeid=v.eid)
                   and not v.eid == veid]
     return vocab
@@ -72,3 +73,15 @@ class ShortComboboxView(editviews.ComboboxView):
     __select__ = is_instance('Project')
     def cell_call(self, row, col):
         self.w(self.cw_rset.get_entity(row, col).dc_title())
+
+
+def registration_callback(vreg):
+    vreg.register_all(globals().values(), __name__)
+    if 'preview' in vreg.config.cubes():
+
+        from cubes.preview.views.forms import PreviewFormMixin
+        class PreviewForm(PreviewFormMixin, AutomaticEntityForm):
+            __select__ = AutomaticEntityForm.__select__ & is_instance('Ticket', 'Version')
+            preview_mode = 'inline'
+
+        vreg.register(PreviewForm)
