@@ -106,9 +106,8 @@ class ProjectTreeComponent(component.EntityCtxComponent):
     context = 'navcontentbottom'
 
     def render_body(self, w):
-        entity = self.cw_rset.get_entity(row, col)
-        rset = entity.cw_adapt_to('ITree').children(entities=False)
-        treeid = 'project_tree_%s' % entity.eid
+        rset = self.entity.cw_adapt_to('ITree').children(entities=False)
+        treeid = 'project_tree_%s' % self.entity.eid
         self.view('treeview', rset=rset, treeid=treeid,
                   initial_thru_ajax=True, w=w)
 
